@@ -45,8 +45,8 @@ from skl_graph.type.plot import (
 
 def Plot(
     edges: Iterable[tuple[str, str, edge_t]],
-    transformation: Callable[[array_t], array_t],
-    vector_transf: Callable[[array_t], array_t],
+    TransformedY: Callable[[array_t], array_t],
+    TransformedYForVector: Callable[[array_t], array_t],
     axes: axes_t,
     edge_styles: edge_styles_h,
     direction_style: direction_style_t,
@@ -62,6 +62,7 @@ def Plot(
         break
 
     PlotEdge = axes.plot if space_dim == 2 else axes.plot3D
+    PlotEdgeLabel = axes.text
 
     for source, target, details in edges:
         if mode is plot_mode_e.SKL_Curve:
@@ -79,7 +80,7 @@ def Plot(
             raise ValueError(
                 f"{mode}: Invalid plotting mode; Valid modes: plot_mode_e.SKL_*"
             )
-        sites[0], sites[1] = sites[1], transformation(sites[0])
+        sites[0], sites[1] = sites[1], TransformedY(sites[0])
 
         if source == target:
             edge_style = edge_styles[1]
@@ -102,7 +103,7 @@ def Plot(
                 directions = list(zip(origin_direction, details.FinalDirection()))
                 directions[0], directions[1] = (
                     directions[1],
-                    vector_transf(directions[0]),
+                    TransformedYForVector(directions[0]),
                 )
                 axes.quiver(
                     *dir_sites,
@@ -111,4 +112,14 @@ def Plot(
                     linewidth=direction_style.size,
                 )
 
-        # TODO: plot edge labels
+        if label_style.show:
+            middle_idx = sites[0].size // 2
+            position = tuple(_crd[middle_idx] for _crd in sites)
+            PlotEdgeLabel(
+                *position,
+                details.uid,
+                fontsize=label_style.size,
+                color=label_style.color,
+                horizontalalignment="center",
+                verticalalignment="center",
+            )
